@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 PYGAME-MENU
 A menu for pygame, simple, lightweight and easy to use.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,6 +29,16 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = [
+
+    # Common classes
+    'BaseImage',
+    'Menu',
+    'Sound',
+    'Theme'
+
+]
+
 # Check if pygame exists, if not maybe the module is being used by setup.py
 __pygame_version__ = None
 try:
@@ -47,7 +53,8 @@ if __pygame_version__ is not None:
     """
     BaseImage: Provides basic image loading and manipulation with pygame
     """
-    import pygame_menu.baseimage
+    import pygame_menu.baseimage  # lgtm [py/import-and-import-from]
+    from pygame_menu.baseimage import BaseImage
 
     """
     Controls: Default controls of menu object and key definition
@@ -72,23 +79,24 @@ if __pygame_version__ is not None:
     """
     Menu: Menu class
     """
-    # noinspection PyUnresolvedReferences
     from pygame_menu.menu import Menu
 
     """
-    ScrollArea: Scroll area class to manage scrolling in Menu
+    ScrollArea: Scrollarea class
     """
-    import pygame_menu.scrollarea
+    import pygame_menu._scrollarea
 
     """
     Sound: Sound class
     """
-    import pygame_menu.sound
+    import pygame_menu.sound  # lgtm [py/import-and-import-from]
+    from pygame_menu.sound import Sound
 
     """
     Themes: Menu themes
     """
-    import pygame_menu.themes
+    import pygame_menu.themes  # lgtm [py/import-and-import-from]
+    from pygame_menu.themes import Theme
 
     """
     Widgets: Menu widgets
@@ -103,9 +111,15 @@ import pygame_menu.version
 """
 Metadata: Information about the project
 """
-__author__ = 'ppizarror'
+__author__ = 'Pablo Pizarro R.'
 __contributors__ = [
+
+    # Author
+    'ppizarror',
+
+    # Contributors
     'anxuae',
+    'apuly',
     'arpruss',
     'asierrayk',
     'DA820',
@@ -117,16 +131,16 @@ __contributors__ = [
     'notrurs',
     'NullP01nt',
     'PandaRoux8',
-    'ppizarror',
     'Rifqi31',
     'thisIsMikeKane',
     'werdeil',
     'zPaw'
+
 ]
 __copyright__ = 'Copyright 2017-2021 Pablo Pizarro R. @ppizarror'
 __description__ = 'A menu for pygame, simple, lightweight and easy to use'
 __email__ = 'pablo@ppizarror.com'
-__keywords__ = 'pygame menu menus gui widget input button pygame-menu'
+__keywords__ = 'pygame menu menus gui widget input button pygame-menu image sound ui'
 __license__ = 'MIT'
 __module_name__ = 'pygame-menu'
 __url__ = 'https://pygame-menu.readthedocs.io/en/latest/'
@@ -134,3 +148,14 @@ __url_bug_tracker__ = 'https://github.com/ppizarror/pygame-menu/issues'
 __url_documentation__ = 'https://pygame-menu.readthedocs.io/en/latest/'
 __url_source_code__ = 'https://github.com/ppizarror/pygame-menu/tree/master/pygame_menu'
 __version__ = pygame_menu.version.ver
+
+"""
+Print pygame-menu version.
+"""
+import os
+
+if 'PYGAME_MENU_HIDE_VERSION' not in os.environ and 'PYGAME_HIDE_SUPPORT_PROMPT' not in os.environ:
+    print('{} {}'.format(__module_name__, __version__))
+
+# Cleanup namespace
+del os
