@@ -1,13 +1,9 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
 
 CONTROLS
-Default controls of menu object and key definition.
-
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
+Default controls of Menu object and key definition.
 
 License:
 -------------------------------------------------------------------------------
@@ -33,6 +29,33 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = [
+
+    # Joy pad
+    'JOY_AXIS_X',
+    'JOY_AXIS_Y',
+    'JOY_BUTTON_BACK',
+    'JOY_BUTTON_SELECT',
+    'JOY_CENTERED',
+    'JOY_DEADZONE',
+    'JOY_DELAY',
+    'JOY_DOWN',
+    'JOY_LEFT',
+    'JOY_REPEAT',
+    'JOY_RIGHT',
+    'JOY_UP',
+
+    # Keyboard events
+    'KEY_APPLY',
+    'KEY_BACK',
+    'KEY_CLOSE_MENU',
+    'KEY_LEFT',
+    'KEY_MOVE_DOWN',
+    'KEY_MOVE_UP',
+    'KEY_RIGHT'
+
+]
+
 import pygame.locals as __locals
 
 # Joy pad
@@ -55,5 +78,5 @@ KEY_BACK = __locals.K_BACKSPACE
 KEY_CLOSE_MENU = __locals.K_ESCAPE
 KEY_LEFT = __locals.K_LEFT
 KEY_MOVE_DOWN = __locals.K_UP
-KEY_MOVE_UP = __locals.K_DOWN
+KEY_MOVE_UP = __locals.K_DOWN  # Consider keys are "inverted"
 KEY_RIGHT = __locals.K_RIGHT
