@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 EVENTS
 Menu events definition and locals.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,6 +29,31 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = [
+
+    # Class
+    'MenuAction',
+
+    # Utils
+    'is_event',
+
+    # Menu events
+    'BACK',
+    'CLOSE',
+    'EXIT',
+    'NONE',
+    'RESET',
+
+    # Pygame events
+    'PYGAME_QUIT',
+    'PYGAME_WINDOWCLOSE',
+
+    # Compatibility
+    'DISABLE_CLOSE'
+
+]
+
+from typing import Any
 import pygame.locals as __locals
 
 
@@ -41,42 +62,40 @@ class MenuAction(object):
     Pygame-menu events.
 
     :param action: Action identifier
-    :type action: int
     """
+    _action: int
 
-    def __init__(self, action):
+    def __init__(self, action: int) -> None:
         assert isinstance(action, int)
         self._action = action
 
-    def __eq__(self, other):
+    def __eq__(self, other: 'MenuAction') -> bool:
         if isinstance(other, MenuAction):
             return self._action == other._action
         return False
 
 
-def is_event(event):
+def is_event(event: Any) -> bool:
     """
     Check if event is pygame_menu event type.
 
     :param event: Event
-    :type event: any
-    :return: True if it's event
-    :rtype: bool
+    :return: ``True`` if it's an event
     """
-    return isinstance(event, MenuAction) or str(type(event)) == "<class 'pygame_menu.events.MenuAction'>"
+    return isinstance(event, MenuAction) or \
+           str(type(event)) == "<class 'pygame_menu.events.MenuAction'>"
 
 
 # Events
 BACK = MenuAction(0)  # Menu back
-CLOSE = MenuAction(1)  # Close menu
-DISABLE_CLOSE = MenuAction(2)  # Menu disable closing
+CLOSE = MenuAction(1)  # Close Menu
+DISABLE_CLOSE = MenuAction(2)  # Compatibility. This will be removed in v4.1. Shorthand for NONE
 EXIT = MenuAction(3)  # Menu exit program
-NONE = MenuAction(4)  # None action
+NONE = MenuAction(4)  # None action. It's the same as 'None'
 RESET = MenuAction(5)  # Menu reset
 
 # Pygame events
 PYGAME_QUIT = __locals.QUIT
-
 PYGAME_WINDOWCLOSE = -1
 if hasattr(__locals, 'WINDOWCLOSE'):
     PYGAME_WINDOWCLOSE = __locals.WINDOWCLOSE
