@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 EXAMPLE - DYNAMIC BUTTON
 Menu with dynamic buttons.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,19 +29,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-import sys
-import os
+__all__ = ['main']
+
+import pygame_menu
+from pygame_menu.examples import create_example_window
+
 from random import randrange
 
-sys.path.insert(0, '../../')
-
-import pygame
-import pygame_menu
-
-pygame.init()
-os.environ['SDL_VIDEO_CENTERED'] = '1'
-surface = pygame.display.set_mode((600, 400))
-
+surface = create_example_window('Example - Dynamic Button Append', (600, 400))
 menu = pygame_menu.Menu(
     height=300,
     theme=pygame_menu.themes.THEME_BLUE,
@@ -54,34 +45,32 @@ menu = pygame_menu.Menu(
 )
 
 
-def add_dynamic_button():
+def add_dynamic_button() -> None:
     """
     Append a button to the menu on demand.
 
     :return: None
     """
-    print('Adding a button dynamically')
-    btn = menu.add_button(randrange(0, 10), None)
+    print('Adding a button dynamically, total: {0}'.format(len(menu.get_widgets()) - 2))
+    btn = menu.add.button(randrange(0, 10))
 
-    def _update_button():
-        count = btn.get_attribute('count', int(btn.get_title())) + 1
-        btn.set_title(count)
-        btn.set_attribute('count', count)
+    def _update_button() -> None:
+        count = btn.get_counter_attribute('count', 1, btn.get_title())
+        btn.set_title(str(count))
 
     btn.update_callback(_update_button)
 
 
-menu.add_text_input('Name: ', default='John Doe')
-menu.add_button('Play', add_dynamic_button)
-menu.add_button('Quit', pygame_menu.events.EXIT)
+menu.add.text_input('Name: ', default='John Doe')
+menu.add.button('Play', add_dynamic_button)
+menu.add.button('Quit', pygame_menu.events.EXIT)
 
 
-def main(test=False):
+def main(test: bool = False) -> None:
     """
     Main function.
 
     :param test: Indicate function is being tested
-    :type test: bool
     :return: None
     """
     menu.mainloop(surface, disable_loop=test)
