@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 EXAMPLE - IMAGE BACKGROUND
 Menu using background image + BaseImage object.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,14 +29,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-from __future__ import print_function
-import sys
-import os
-
-sys.path.insert(0, '../../')
+__all__ = ['main']
 
 import pygame
 import pygame_menu
+from pygame_menu.examples import create_example_window
+
+from typing import Optional
 
 # -----------------------------------------------------------------------------
 # Constants and global variables
@@ -48,17 +43,14 @@ import pygame_menu
 FPS = 60
 WINDOW_SIZE = (640, 480)
 
-# noinspection PyTypeChecker
-sound = None  # type: pygame_menu.sound.Sound
-# noinspection PyTypeChecker
-surface = None  # type: pygame.Surface
-# noinspection PyTypeChecker
-main_menu = None  # type: pygame_menu.Menu
+sound: Optional['pygame_menu.sound.Sound'] = None
+surface: Optional['pygame.Surface'] = None
+main_menu: Optional['pygame_menu.Menu'] = None
 
 # -----------------------------------------------------------------------------
 # Load image
 # -----------------------------------------------------------------------------
-background_image = pygame_menu.baseimage.BaseImage(
+background_image = pygame_menu.BaseImage(
     image_path=pygame_menu.baseimage.IMAGE_EXAMPLE_WALLPAPER
 )
 
@@ -66,7 +58,7 @@ background_image = pygame_menu.baseimage.BaseImage(
 # -----------------------------------------------------------------------------
 # Methods
 # -----------------------------------------------------------------------------
-def main_background():
+def main_background() -> None:
     """
     Background color of the main menu, on this function user can plot
     images, play sounds, etc.
@@ -76,12 +68,11 @@ def main_background():
     background_image.draw(surface)
 
 
-def main(test=False):
+def main(test: bool = False) -> None:
     """
     Main program.
 
     :param test: Indicate function is being tested
-    :type test: bool
     :return: None
     """
 
@@ -93,14 +84,9 @@ def main(test=False):
     global surface
 
     # -------------------------------------------------------------------------
-    # Init pygame
+    # Create window
     # -------------------------------------------------------------------------
-    pygame.init()
-    os.environ['SDL_VIDEO_CENTERED'] = '1'
-
-    # Create pygame screen and objects
-    surface = pygame.display.set_mode(WINDOW_SIZE)
-    pygame.display.set_caption('Example - Image Background')
+    surface = create_example_window('Example - Image Background', WINDOW_SIZE)
     clock = pygame.time.Clock()
 
     # -------------------------------------------------------------------------
@@ -118,6 +104,9 @@ def main(test=False):
     )
 
     widget_colors_theme = pygame_menu.themes.THEME_ORANGE.copy()
+    widget_colors_theme.widget_margin = (0, 10)
+    widget_colors_theme.widget_padding = 0
+    widget_colors_theme.widget_selection_effect.margin_xy(10, 5)
     widget_colors_theme.widget_font_size = 20
     widget_colors_theme.set_background_color_opacity(0.5)  # 50% opacity
 
@@ -128,28 +117,31 @@ def main(test=False):
         width=WINDOW_SIZE[0] * 0.8
     )
 
-    button_image = pygame_menu.baseimage.BaseImage(pygame_menu.baseimage.IMAGE_EXAMPLE_CARBON_FIBER)
+    button_image = pygame_menu.BaseImage(pygame_menu.baseimage.IMAGE_EXAMPLE_CARBON_FIBER)
 
-    widget_colors.add_button('Opaque color button', None,
+    widget_colors.add.button('Opaque color button',
                              background_color=(100, 100, 100))
-    widget_colors.add_button('Transparent color button', None,
+    widget_colors.add.button('Transparent color button',
                              background_color=(50, 50, 50, 200), font_size=40)
-    widget_colors.add_button('Transparent background inflate to selection effect', None,
-                             background_color=(50, 50, 50, 200), margin=(0, 15)
-                             ).expand_background_inflate_to_selection_effect()
-    widget_colors.add_button('Background inflate + font background color', None,
-                             background_color=(50, 50, 50, 200), font_background_color=(200, 200, 200)
-                             ).expand_background_inflate_to_selection_effect()
-    widget_colors.add_button('This inflates background to match selection effect', None,
-                             background_color=button_image, font_color=(255, 255, 255), font_size=15
+    widget_colors.add.button('Transparent background inflate to selection effect',
+                             background_color=(50, 50, 50, 200),
+                             margin=(0, 15)).background_inflate_to_selection_effect()
+    widget_colors.add.button('Background inflate + font background color',
+                             background_color=(50, 50, 50, 200),
+                             font_background_color=(200, 200, 200)
+                             ).background_inflate_to_selection_effect()
+    widget_colors.add.button('This inflates background to match selection effect',
+                             background_color=button_image,
+                             font_color=(255, 255, 255), font_size=15
                              ).selection_expand_background = True
-    widget_colors.add_button('This is already inflated to match selection effect', None,
-                             background_color=button_image, font_color=(255, 255, 255), font_size=15
-                             ).expand_background_inflate_to_selection_effect()
+    widget_colors.add.button('This is already inflated to match selection effect',
+                             background_color=button_image,
+                             font_color=(255, 255, 255), font_size=15
+                             ).background_inflate_to_selection_effect()
 
-    main_menu.add_button('Test different widget colors', widget_colors)
-    main_menu.add_button('Another fancy button', lambda: print('This button has been pressed'))
-    main_menu.add_button('Quit', pygame_menu.events.EXIT)
+    main_menu.add.button('Test different widget colors', widget_colors)
+    main_menu.add.button('Another fancy button', lambda: print('This button has been pressed'))
+    main_menu.add.button('Quit', pygame_menu.events.EXIT)
 
     # -------------------------------------------------------------------------
     # Main loop
