@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 VERSION
 Library version.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,6 +29,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = ['Version', 'vernum', 'ver', 'rev']
+
+from typing import Tuple
+
 
 class Version(tuple):
     """
@@ -42,14 +42,14 @@ class Version(tuple):
     __slots__ = ()
     fields = 'major', 'minor', 'patch'
 
-    def __new__(cls, major, minor, patch):
+    def __new__(cls, major, minor, patch) -> Tuple:
         return tuple.__new__(cls, (major, minor, patch))
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         fields = ('{}={}'.format(fld, val) for fld, val in zip(self.fields, self))
         return '{}({})'.format(str(self.__class__.__name__), ', '.join(fields))
 
-    def __str__(self):
+    def __str__(self) -> str:
         return '{}.{}.{}'.format(*self)
 
     major = property(lambda self: self[0])
@@ -57,6 +57,6 @@ class Version(tuple):
     patch = property(lambda self: self[2])
 
 
-vernum = Version(3, 5, 8)
+vernum = Version(4, 0, 0)
 ver = str(vernum)
 rev = ''
