@@ -1,13 +1,9 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
 
 WIDGETS
-Widgets elements that can be added to the menu.
-
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
+Widgets elements that can be added to the Menu.
 
 License:
 -------------------------------------------------------------------------------
@@ -34,15 +30,29 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
 # Widgets core
-import pygame_menu.widgets.core
+import pygame_menu.widgets.core  # lgtm [py/import-and-import-from]
+from pygame_menu.widgets.core import Widget
 
 # Selection
-from pygame_menu.widgets.selection import HighlightSelection, LeftArrowSelection, NoneSelection, RightArrowSelection
+from pygame_menu.widgets.selection import HighlightSelection, LeftArrowSelection, \
+    NoneSelection, RightArrowSelection
 
 # Widgets
-from pygame_menu.widgets.widget import Button, ColorInput, Image, Label, ScrollBar, Selector, TextInput, VMargin
+from pygame_menu.widgets.widget import Button, ColorInput, DropSelect, \
+    DropSelectMultiple, Frame, HMargin, Image, Label, MenuBar, NoneWidget, ScrollBar, \
+    Selector, SurfaceWidget, Table, TextInput, ToggleSwitch, VMargin
 
-# Menubar and positions
-from pygame_menu.widgets.widget import MenuBar, MENUBAR_STYLE_ADAPTIVE, MENUBAR_STYLE_SIMPLE, \
-    MENUBAR_STYLE_TITLE_ONLY, MENUBAR_STYLE_TITLE_ONLY_DIAGONAL, MENUBAR_STYLE_NONE, MENUBAR_STYLE_UNDERLINE, \
-    MENUBAR_STYLE_UNDERLINE_TITLE
+# Widget constants
+from pygame_menu.widgets.widget.colorinput import COLORINPUT_TYPE_RGB, \
+    COLORINPUT_TYPE_HEX, COLORINPUT_HEX_FORMAT_UPPER, COLORINPUT_HEX_FORMAT_NONE, \
+    COLORINPUT_HEX_FORMAT_LOWER
+
+from pygame_menu.widgets.widget.frame import FRAME_DEFAULT_TITLE_BACKGROUND_COLOR, \
+    FRAME_TITLE_BUTTON_CLOSE, FRAME_TITLE_BUTTON_MAXIMIZE, FRAME_TITLE_BUTTON_MINIMIZE
+
+from pygame_menu.widgets.widget.menubar import MENUBAR_STYLE_ADAPTIVE, \
+    MENUBAR_STYLE_SIMPLE, MENUBAR_STYLE_TITLE_ONLY, MENUBAR_STYLE_TITLE_ONLY_DIAGONAL, \
+    MENUBAR_STYLE_NONE, MENUBAR_STYLE_UNDERLINE, MENUBAR_STYLE_UNDERLINE_TITLE
+
+from pygame_menu.widgets.widget.selector import SELECTOR_STYLE_CLASSIC, \
+    SELECTOR_STYLE_FANCY
