@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 LEFT ARROW CLASS
 Selector with a left arrow on the item.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,10 +29,16 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = ['ArrowSelection']
+
 import pygame
-from pygame_menu.utils import assert_vector2
+import pygame_menu
+
+from pygame_menu.utils import assert_vector
 from pygame_menu.widgets.core import Selection
 
+from pygame_menu._types import NumberType, Tuple2IntType, Optional, NumberInstance
+
 SELECTOR_CLOCK = pygame.time.Clock()
 
 
@@ -46,62 +48,60 @@ class ArrowSelection(Selection):
     Parent class for left and right arrow selection classes.
 
     :param margin_left: Left margin
-    :type margin_left: int, float
     :param margin_right: Right margin
-    :type margin_right: int, float
     :param margin_top: Top margin
-    :type margin_top: int, float
     :param margin_bottom: Bottom margin
-    :type margin_bottom: int, float
-    :param arrow_size: Size of arrow on *(x,y)* axis *(width,height)*
-    :type arrow_size: tuple, list
+    :param arrow_size: Size of arrow on x-axis and y-axis (width, height) in px
     :param arrow_vertical_offset: Vertical offset of the arrow
-    :type arrow_vertical_offset: int
-    :param blink_ms: Milliseconds between each blink, if *0* blinking is disabled
-    :type blink_ms: int, float
+    :param blink_ms: Milliseconds between each blink, if ``0`` blinking is disabled
     """
+    _arrow_vertical_offset: int
+    _arrow_size: Tuple2IntType
+    _blink_ms: NumberType
+    _blink_time: NumberType
+    _blink_status: bool
+    _last_widget: Optional['pygame_menu.widgets.Widget']
 
-    def __init__(self, margin_left, margin_right, margin_top, margin_bottom,
-                 arrow_size=(10, 15), arrow_vertical_offset=0, blink_ms=0):
+    def __init__(self, margin_left: NumberType, margin_right: NumberType, margin_top: NumberType,
+                 margin_bottom: NumberType, arrow_size: Tuple2IntType = (10, 15),
+                 arrow_vertical_offset: NumberType = 0, blink_ms: NumberType = 0) -> None:
         super(ArrowSelection, self).__init__(
             margin_left=margin_left,
             margin_right=margin_right,
             margin_top=margin_top,
             margin_bottom=margin_bottom
         )
-        assert_vector2(arrow_size)
-        assert isinstance(arrow_vertical_offset, (int, float))
+
+        assert_vector(arrow_size, 2, int)
+        assert isinstance(arrow_vertical_offset, NumberInstance)
         assert isinstance(blink_ms, int)
         assert arrow_size[0] > 0 and arrow_size[1] > 0, 'arrow size must be greater than zero'
         assert blink_ms >= 0, 'blinking milliseconds must be greater than or equal to zero'
-        self._arrow_vertical_offset = arrow_vertical_offset
-        self._arrow_size = (arrow_size[0], arrow_size[1])  # type: tuple
+
+        self._arrow_vertical_offset = int(arrow_vertical_offset)
+        self._arrow_size = (arrow_size[0], arrow_size[1])
         self._blink_ms = blink_ms
         self._blink_time = 0
         self._blink_status = True
         self._last_widget = None
 
     # noinspection PyMissingOrEmptyDocstring
-    def draw(self, surface, widget):
+    def draw(self, surface: 'pygame.Surface', widget: 'pygame_menu.widgets.Widget') -> 'Selection':
         raise NotImplementedError('override is mandatory')
 
-    def _draw_arrow(self, surface, widget, a, b, c):
+    def _draw_arrow(self, surface: 'pygame.Surface', widget: 'pygame_menu.widgets.Widget',
+                    a: Tuple2IntType, b: Tuple2IntType, c: Tuple2IntType) -> None:
         """
         Draw the selection arrow.
 
         :param surface: Surface to draw
-        :type surface: :py:class:`pygame.Surface`
         :param widget: Widget object
-        :type widget: :py:class:`pygame_menu.widgets.core.Widget`
         :param a: Arrow coord A
-        :type a: tuple
         :param b: Arrow coord B
-        :type b: tuple
         :param c: Arrow coord C
-        :type c: tuple
         :return: None
         """
-        SELECTOR_CLOCK.tick(60)
+        SELECTOR_CLOCK.tick(60)  # As blink is in ms
         self._blink_time += SELECTOR_CLOCK.get_time()
 
         # Switch the blinking if the time exceeded or the widget has changed
