@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 RIGHT ARROW CLASS
 Selector with a right arrow on the item.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,31 +29,37 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = ['RightArrowSelection']
+
+import pygame
+import pygame_menu
+
+from pygame_menu.widgets.core import Selection
 from pygame_menu.widgets.selection.arrow_selection import ArrowSelection
 
+from pygame_menu._types import Tuple2IntType, NumberType, NumberInstance
+
 
 class RightArrowSelection(ArrowSelection):
     """
-    Widget selection right arrow class.
-    Creates an arrow to the right of the selected menu item.
+    Widget selection right arrow class. Creates an arrow to the right of the
+    selected Menu item.
 
-    :param arrow_size: Size of arrow on *(x,y)* axis *(width,height)*
-    :type arrow_size: tuple, list
+    :param arrow_size: Size of arrow on x-axis and y-axis (width, height) in px
     :param arrow_left_margin: Distance from the arrow to the widget
-    :type arrow_left_margin: int, float
     :param arrow_vertical_offset: Vertical offset of the arrow
-    :type arrow_vertical_offset: int
-    :param blink_ms: Milliseconds between each blink, if *0* blinking is disabled
-    :type blink_ms: int, float
+    :param blink_ms: Milliseconds between each blink, if ``0`` blinking is disabled
     """
+    _arrow_left_margin: int
 
-    def __init__(self,
-                 arrow_size=(10, 15),
-                 arrow_left_margin=3,
-                 arrow_vertical_offset=0,
-                 blink_ms=0
-                 ):
-        assert isinstance(arrow_left_margin, (int, float))
+    def __init__(
+            self,
+            arrow_size: Tuple2IntType = (10, 15),
+            arrow_left_margin: int = 3,
+            arrow_vertical_offset: int = 0,
+            blink_ms: NumberType = 0
+    ) -> None:
+        assert isinstance(arrow_left_margin, NumberInstance)
         assert arrow_left_margin >= 0, 'margin cannot be negative'
         super(RightArrowSelection, self).__init__(
             margin_left=0,
@@ -70,17 +72,18 @@ class RightArrowSelection(ArrowSelection):
         self._arrow_left_margin = arrow_left_margin
 
     # noinspection PyMissingOrEmptyDocstring
-    def draw(self, surface, widget):
-        rect = widget.get_rect()
+    def draw(self, surface: 'pygame.Surface', widget: 'pygame_menu.widgets.Widget') -> 'Selection':
         #                 /A
         # widget        B
         #                \ C
         #       <------>
         #        margin
+        rect = widget.get_rect()
         a = (rect.topright[0] + self._arrow_size[0] + self._arrow_left_margin,
-             rect.midright[1] - self._arrow_size[1] / 2 + self._arrow_vertical_offset)
+             int(rect.midright[1] - self._arrow_size[1] / 2 + self._arrow_vertical_offset))
         b = (rect.midright[0] + self._arrow_left_margin,
              rect.midright[1] + self._arrow_vertical_offset)
         c = (rect.bottomright[0] + self._arrow_size[0] + self._arrow_left_margin,
-             rect.midright[1] + self._arrow_size[1] / 2 + self._arrow_vertical_offset)
+             int(rect.midright[1] + self._arrow_size[1] / 2 + self._arrow_vertical_offset))
         super(RightArrowSelection, self)._draw_arrow(surface, widget, a, b, c)
+        return self
