@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 IMAGE
 Image widget class, adds a simple image.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,8 +29,19 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = ['Image']
+
+from io import BytesIO
+from pathlib import Path
+
+import pygame
+
 from pygame_menu.baseimage import BaseImage
-from pygame_menu.widgets.core import Widget
+from pygame_menu.utils import assert_vector
+from pygame_menu.widgets import Widget
+
+from pygame_menu._types import Union, NumberType, CallbackType, Tuple2NumberType,\
+    Optional, NumberInstance, EventVectorType
 
 
 # noinspection PyMissingOrEmptyDocstring
@@ -42,29 +49,38 @@ class Image(Widget):
     """
     Image widget.
 
-    :param image_path: Path of the image or BaseImage object. If BaseImage object is provided drawing mode is not considered. It can be a string or :py:class:`pathlib.Path` on ``Python 3+``
-    :type image_path: str, :py:class:`pathlib.Path`, BaseImage
-    :param image_id: Image ID
-    :type image_id: str
-    :param angle: Angle of the image in degrees (clockwise)
-    :type angle: int, float
-    :param scale: Scale of the image *(x,y)*
-    :type scale: tuple, list
-    :param scale_smooth: Scale is smoothed
-    :type scale_smooth: bool
-    """
+    .. note::
 
-    def __init__(self,
-                 image_path,
-                 image_id='',
-                 angle=0,
-                 scale=(1, 1),
-                 scale_smooth=True
-                 ):
-        assert isinstance(angle, (int, float))
-        assert isinstance(scale, (tuple, list))
+        This class redefines all widget transformations.
+
+    :param image_path: Path of the image, BytesIO object, or :py:class:`pygame_menu.baseimage.BaseImage` object. If :py:class:`pygame_menu.baseimage.BaseImage` object is provided drawing mode is not considered
+    :param image_id: Image ID
+    :param angle: Angle of the image in degrees (clockwise)
+    :param onselect: Function when selecting the widget
+    :param scale: Scale of the image on x-axis and y-axis (x, y) in px
+    :param scale_smooth: Scale is smoothed
+    """
+    _image: 'BaseImage'
+
+    def __init__(
+            self,
+            image_path: Union[str, 'BaseImage', 'Path', 'BytesIO'],
+            angle: NumberType = 0,
+            image_id: str = '',
+            onselect: CallbackType = None,
+            scale: Tuple2NumberType = (1, 1),
+            scale_smooth: bool = True
+    ) -> None:
+        assert isinstance(image_path, (str, Path, BaseImage, BytesIO))
+        assert isinstance(image_id, str)
+        assert isinstance(angle, NumberInstance)
         assert isinstance(scale_smooth, bool)
-        super(Image, self).__init__(widget_id=image_id)
+        assert_vector(scale, 2)
+
+        super(Image, self).__init__(
+            onselect=onselect,
+            widget_id=image_id
+        )
 
         if isinstance(image_path, BaseImage):
             self._image = image_path
@@ -73,63 +89,73 @@ class Image(Widget):
             self._image.rotate(angle)
             self._image.scale(scale[0], scale[1], smooth=scale_smooth)
 
-        self.selection_effect_enabled = False
+    def set_title(self, title: str) -> 'Image':
+        return self
 
-    def get_image(self):
+    def get_image(self) -> 'BaseImage':
         """
-        Gets the BaseImage object from widget.
+        Gets the :py:class:`pygame_menu.baseimage.BaseImage` object from widget.
 
         :return: Widget image
-        :rtype: BaseImage
         """
         return self._image
 
-    def set_image(self, image):
+    def set_image(self, image: 'BaseImage') -> None:
         """
-        Set the BaseImage object from widget.
+        Set the :py:class:`pygame_menu.baseimage.BaseImage` object from widget.
 
-        :param image: BaseImage object
-        :type image: BaseImage
+        :param image: Image object
         :return: None
         """
         self._image = image
         self._surface = None
         self._render()
 
-    def _apply_font(self):
+    def _apply_font(self) -> None:
         pass
 
-    def rotate(self, angle):
+    def rotate(self, angle: NumberType) -> 'Image':
         self._image.rotate(angle)
         self._surface = None
+        return self
 
-    def flip(self, x, y):
+    def flip(self, x: bool, y: bool) -> 'Image':
         if x or y:
             self._image.flip(x, y)
             self._surface = None
+        return self
 
-    def scale(self, width, height, smooth=False):
+    def scale(self, width: NumberType, height: NumberType, smooth: bool = False) -> 'Image':
         self._image.scale(width, height, smooth)
         self._surface = None
+        return self
 
-    def resize(self, width, height, smooth=False):
+    def resize(self, width: NumberType, height: NumberType, smooth: bool = False) -> 'Image':
         self._image.resize(width, height, smooth)
         self._surface = None
+        return self
 
-    # noinspection PyMissingOrEmptyDocstring
-    def draw(self, surface):
-        self._render()
+    def set_max_width(self, *args, **kwargs) -> 'Image':
+        return self
+
+    def set_max_height(self, *args, **kwargs) -> 'Image':
+        return self
+
+    def _draw(self, surface: 'pygame.Surface') -> None:
         surface.blit(self._surface, self._rect.topleft)
 
-    def _render(self):
+    def _render(self) -> Optional[bool]:
         if self._surface is not None:
             return True
-        self._surface = self._image.get_surface()
+        self._surface = self._image.get_surface(new=False)
         self._rect.width, self._rect.height = self._surface.get_size()
-        if not self._render_hash_changed(self.visible):
+        if not self._render_hash_changed(self._visible):
             return True
-        self._menu_surface_needs_update = True  # Force menu update
+        self.force_menu_surface_update()
 
-    # noinspection PyMissingOrEmptyDocstring
-    def update(self, events):
+    def update(self, events: EventVectorType) -> bool:
+        self.apply_update_callbacks(events)
+        for event in events:
+            if self._check_mouseover(event):
+                break
         return False
